@@ -65,6 +65,7 @@ where
     where
         R: AsyncReadExt + Unpin,
     {
+        debug_assert!(size != 0);
         debug_assert!(self.payload.len() == MAX_SIZE);
 
         let size = self
@@ -73,10 +74,6 @@ where
             .await
             .map_err(|_| Error::PacketSize)?;
 
-        if size == 0 {
-            return Err(Error::PacketSize);
-        }
-
         let mut payload = POOL_VEC_PACKET.create();
         debug_assert!(payload.is_empty());
         payload.extend_from_slice(&self.payload[0..size]);
