@@ -46,21 +46,20 @@ pub fn to_bytes(cmd: u16, payload: Option<&[u8]>) -> PoolObjectContainer<Vec<u8>
     let size = payload_size as u32;
     let target_capacity = HEADER_SIZE + size as usize;
     let mut vec = POOL_VEC.create();
-    let current_capacity = vec.capacity();
-    if target_capacity > current_capacity {
-        debug_assert!(vec.capacity() < target_capacity);
-        let diff = target_capacity - current_capacity;
-        vec.reserve_exact(diff);
-    }
+    debug_assert!(vec.is_empty());
 
+    vec.reserve(target_capacity);
     debug_assert!(vec.capacity() >= target_capacity);
 
     vec.put_u32(size);
     vec.put_u16(cmd);
+
     if let Some(payload) = payload {
-        vec.extend_from_slice(payload.as_ref());
+        vec.extend(payload.as_ref());
     }
 
+    debug_assert!(vec.len() == target_capacity);
+
     vec
 }
 
@@ -81,4 +80,24 @@ mod tests {
         assert_eq!(op_code, 1);
         assert_eq!(result[6..], content);
     }
+
+    #[test]
+    fn test_to_bytes_loop() {
+        for i in 0..25 {
+            if i % 2 == 0 {
+                let mut x = POOL_VEC.create();
+                x.extend_from_slice(&[0, 5, 5, 25]);
+                drop(x);
+            }
+
+            let content = [1, 1, 2];
+            let result = to_bytes(1, Some(&content));
+            assert_eq!(result.len(), 9);
+            let size = u32::from_be_bytes(result[..4].try_into().unwrap());
+            assert_eq!(size, 3);
+            let op_code = u16::from_be_bytes(result[4..6].try_into().unwrap());
+            assert_eq!(op_code, 1);
+            assert_eq!(result[6..], content);
+        }
+    }
 }
